@@ -11,6 +11,6 @@ My::Genre->has_many( albums => 'My::Album' );
 sub moniker { 'genre' }
 sub class_title { 'Genre' }
 sub class_plural { 'Genres' }
-sub class_description { '' }
+sub class_description { 'The Genre class' }
 
 1;
