@@ -11,6 +11,6 @@ My::Track->has_a( album => 'My::Album' );
 sub moniker { 'track' }
 sub class_title { 'Track' }
 sub class_plural { 'Tracks' }
-sub class_description { 'CDF is designed to be subclassed and extended. It works out of the box, but its most likely role is as a framework for something much more complex.' }
+sub class_description { 'The track class.' }
 
 1;
